#!/usr/bin/env python3
# coding=UTF-8
#
# Copyright 2022. quinn.7@foxmail.com All rights reserved.
# Author :: cat7
# Email  :: quinn.7@foxmail.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, 
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# =============================================================================
"""
[ rains 全栈自动化测试框架 ]

"""

__version__ = '0.3.8'

__name__ = 'rains'
__author__ = 'cat7'
__email__ = 'quinn.7@foxmail.com'
__description__ = '这是一个开箱即用、稳定且高效的工程化全栈自动化测试框架。'
__url__ = 'https://gitee.com/catcat7/rains'
